# coding: utf-8

from __future__ import absolute_import
from datetime import date, datetime  # noqa: F401

from typing import List, Dict  # noqa: F401

from rlbot_action_server.models.base_model_ import Model
from rlbot_action_server import util


class StrategicCategory(Model):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    NEUTRAL = "neutral"
    OFFENSE = "offense"
    DEFENSE = "defense"
    def __init__(self):  # noqa: E501
        """StrategicCategory - a model defined in Swagger

        """
        self.swagger_types = {
        }

        self.attribute_map = {
        }

    @classmethod
    def from_dict(cls, dikt) -> 'StrategicCategory':
        """Returns the dict as a model

        :param dikt: A dict.
        :type: dict
        :return: The StrategicCategory of this StrategicCategory.  # noqa: E501
        :rtype: StrategicCategory
        """
        return util.deserialize_model(dikt, cls)
